@@ -38,10 +38,10 @@ class CuttleFishPlugin : public KTextEditor::Plugin
     Q_OBJECT
 
 public:
-    explicit CuttleFishPlugin(QObject *parent = 0, const QList<QVariant> & = QList<QVariant>());
-    virtual ~CuttleFishPlugin();
+    explicit CuttleFishPlugin(QObject *parent = nullptr, const QList<QVariant> & = QList<QVariant>());
+    ~CuttleFishPlugin() override;
 
-    QObject *createView(KTextEditor::MainWindow *mainWindow) Q_DECL_OVERRIDE;
+    QObject *createView(KTextEditor::MainWindow *mainWindow) override;
 
 private Q_SLOTS:
     void contextMenuAboutToShow (KTextEditor::View *view, QMenu *menu);
